/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.extension.xar.internal.handler.packager.xml;

import java.util.Locale;

import org.xml.sax.SAXException;
import org.xwiki.component.manager.ComponentManager;
import org.xwiki.extension.xar.internal.handler.packager.XarEntry;
import org.xwiki.localization.LocaleUtils;
import org.xwiki.model.reference.LocalDocumentReference;

/**
 * @version $Id: 44b01c6e06f6c3f7b328613b4ce345483f8aa8b6 $
 * @since 4.0M1
 */
public class XarPageLimitedHandler extends AbstractHandler
{
    private XarEntry xarEntry = new XarEntry();

    private String spaceName;

    private LocalDocumentReference pageReference;

    public XarPageLimitedHandler(ComponentManager componentManager)
    {
        super(componentManager);

        setCurrentBean(this);

        this.pageReference = new LocalDocumentReference("space", "page");

        addsupportedElements("name");
        addsupportedElements("web");
        addsupportedElements("language");
    }

    public XarEntry getXarEntry()
    {
        return this.xarEntry;
    }

    private Locale toLocale(String str)
    {
        Locale locale;
        try {
            locale = LocaleUtils.toLocale(str);
        } catch (Exception e) {
            locale = Locale.ROOT;
        }

        return locale;
    }

    @Override
    protected void endElementInternal(String uri, String localName, String qName) throws SAXException
    {
        if (qName.equals("language")) {
            if (this.value.length() > 0) {
                this.xarEntry.setLocale(toLocale(this.value.toString()));
            } else {
                this.xarEntry.setLocale(Locale.ROOT);
            }
        } else if (qName.equals("name")) {
            this.pageReference = new LocalDocumentReference(this.spaceName, this.value.toString());
            this.xarEntry.setDocumentReference(this.pageReference);
        } else if (qName.equals("web")) {
            this.spaceName = this.value.toString();
            this.xarEntry.setDocumentReference(this.pageReference);
        } else {
            super.endElementInternal(uri, localName, qName);
        }
    }
}
