/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.wikistream.type;

import org.junit.Assert;
import org.junit.Test;

/**
 * Validate {@link WikiStreamType}.
 * 
 * @version $Id: 5de6af7e3f4ca931dff79c9b15dd29552a4bb348 $
 */
public class WikiStreamTypeTest
{
    // Tests

    @Test
    public void testSerializeWithDataAndVersion()
    {
        WikiStreamType type = new WikiStreamType(new WikiType("type"), "data", "version");

        Assert.assertEquals("type+data/version", type.serialize());
    }

    @Test
    public void testUnserializeWithDataAndVersion()
    {
        WikiStreamType type = WikiStreamType.unserialize("type+data/version");

        Assert.assertEquals("type", type.getType().getId());
        Assert.assertEquals("data", type.getDataFormat());
        Assert.assertEquals("version", type.getVersion());
    }

    @Test
    public void testUnserializeWithData()
    {
        WikiStreamType type = WikiStreamType.unserialize("type+data");

        Assert.assertEquals("type", type.getType().getId());
        Assert.assertEquals("data", type.getDataFormat());
        Assert.assertNull(type.getVersion());
    }

    @Test
    public void testUnserializeWithEmptyData()
    {
        WikiStreamType type = WikiStreamType.unserialize("type+");

        Assert.assertEquals("type", type.getType().getId());
        Assert.assertEquals("", type.getDataFormat());
        Assert.assertNull(type.getVersion());
    }

    @Test
    public void testUnserializeWithVersion()
    {
        WikiStreamType type = WikiStreamType.unserialize("type/version");

        Assert.assertEquals("type", type.getType().getId());
        Assert.assertNull(type.getDataFormat());
        Assert.assertEquals("version", type.getVersion());
    }

    @Test
    public void testUnserializeWithEmptyVersion()
    {
        WikiStreamType type = WikiStreamType.unserialize("type/");

        Assert.assertEquals("type", type.getType().getId());
        Assert.assertNull(type.getDataFormat());
        Assert.assertEquals("", type.getVersion());
    }
}
